@@ -1,5 +1,4 @@
-/*  crypto/gui/certificatelineedit.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2016 Bundesamt für Sicherheit in der Informationstechnik
     SPDX-FileContributor: Intevation GmbH
@@ -412,8 +411,9 @@ CertificateLineEdit::Private::Private(CertificateLineEdit *qq, AbstractKeyListMo
 
 void CertificateLineEdit::Private::openDetailsDialog()
 {
-    if (!q->key().isNull()) {
-        auto cmd = new Commands::DetailsCommand{q->key()};
+    if (!q->key().isNull() || !q->userID().isNull()) {
+        const Key key = !q->key().isNull() ? q->key() : q->userID().parent();
+        auto cmd = new Commands::DetailsCommand{key};
         cmd->setParentWidget(q);
         cmd->start();
     } else if (!q->group().isNull()) {
@@ -603,22 +603,23 @@ void CertificateLineEdit::Private::updateKey(CursorPositioning positioning)
     mGroup = newGroup;
     mUserId = newUserId;
 
+    using namespace Kleo::Formatting;
     if (!mKey.isNull()) {
         /* FIXME: This needs to be solved by a multiple UID supporting model */
         mStatus = Status::Success;
-        ui.lineEdit.setToolTip(Formatting::toolTip(mKey, Formatting::ToolTipOption::AllOptions));
+        ui.lineEdit.setToolTip(Formatting::toolTip(mKey, Validity | Issuer | Subject | Fingerprint | ExpiryDates | UserIDs));
         if (!mEditingInProgress) {
             setTextWithBlockedSignals(Formatting::summaryLine(mKey), positioning);
         }
     } else if (!mGroup.isNull()) {
         mStatus = Status::Success;
-        ui.lineEdit.setToolTip(Formatting::toolTip(mGroup, Formatting::ToolTipOption::AllOptions));
+        ui.lineEdit.setToolTip(Formatting::toolTip(mGroup, Validity | Issuer | Subject | Fingerprint | ExpiryDates | UserIDs));
         if (!mEditingInProgress) {
             setTextWithBlockedSignals(Formatting::summaryLine(mGroup), positioning);
         }
     } else if (!mUserId.isNull()) {
         mStatus = Status::Success;
-        ui.lineEdit.setToolTip(Formatting::toolTip(mUserId, Formatting::ToolTipOption::AllOptions));
+        ui.lineEdit.setToolTip(Formatting::toolTip(mUserId, Validity | Issuer | Subject | Fingerprint | ExpiryDates | UserIDs));
         if (!mEditingInProgress) {
             setTextWithBlockedSignals(Formatting::summaryLine(mUserId), positioning);
         }
